@@ -171,8 +171,7 @@ class TestOptional(TestCase):
             self.fail("Unexpected failure: %s" % e)
 
     def test_optional_fail(self):
-        x = {
-            "prop02":"blah"
-        }
-
+        x = { "prop02":"blah" }
+        self.assertRaises(ValueError, validictory.validate, x, self.schema)
+        x = { "prop04":True }  # should still fail
         self.assertRaises(ValueError, validictory.validate, x, self.schema)
